#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-6XZv3AnhJ1a6jeiz3PipEQ
key:                  colourista-0.1.0.2-6XZv3AnhJ1a6jeiz3PipEQ
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  2a404c1ebe23e1f44405f8ee5676f67d
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-6XZv3AnhJ1a6jeiz3PipEQ
depends:
    ansi-terminal-1.1-835k7LpO3VY5VImF1e2otx base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

